@@ -1,8 +1,6 @@
 """A base class session manager."""
-
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
-
 import uuid
 
 try:
@@ -22,33 +20,35 @@ from jupyter_server.traittypes import InstanceFromClasses
 
 class SessionManager(LoggingConfigurable):
 
-    kernel_manager = Instance('jupyter_server.services.kernels.kernelmanager.MappingKernelManager')
+    kernel_manager = Instance("jupyter_server.services.kernels.kernelmanager.MappingKernelManager")
     contents_manager = InstanceFromClasses(
         [
-            'jupyter_server.services.contents.manager.ContentsManager',
-            'notebook.services.contents.manager.ContentsManager'
+            "jupyter_server.services.contents.manager.ContentsManager",
+            "notebook.services.contents.manager.ContentsManager",
         ]
     )
 
     # Session database initialized below
     _cursor = None
     _connection = None
-    _columns = {'session_id', 'path', 'name', 'type', 'kernel_id'}
+    _columns = {"session_id", "path", "name", "type", "kernel_id"}
 
     @property
     def cursor(self):
         """Start a cursor and create a database called 'session'"""
         if self._cursor is None:
             self._cursor = self.connection.cursor()
-            self._cursor.execute("""CREATE TABLE session
-                (session_id, path, name, type, kernel_id)""")
+            self._cursor.execute(
+                """CREATE TABLE session
+                (session_id, path, name, type, kernel_id)"""
+            )
         return self._cursor
 
     @property
     def connection(self):
         """Start a database connection"""
         if self._connection is None:
-            self._connection = sqlite3.connect(':memory:')
+            self._connection = sqlite3.connect(":memory:")
             self._connection.row_factory = sqlite3.Row
         return self._connection
 
@@ -82,21 +82,29 @@ class SessionManager(LoggingConfigurable):
         "Create a uuid for a new session"
         return str(uuid.uuid4())
 
-    async def create_session(self, path=None, name=None, type=None, kernel_name=None, kernel_id=None):
+    async def create_session(
+        self, path=None, name=None, type=None, kernel_name=None, kernel_id=None
+    ):
         """Creates a session and returns its model"""
         session_id = self.new_session_id()
         if kernel_id is not None and kernel_id in self.kernel_manager:
             pass
         else:
-            kernel_id = await self.start_kernel_for_session(session_id, path, name, type, kernel_name)
-        result = await self.save_session(session_id, path=path, name=name, type=type, kernel_id=kernel_id)
+            kernel_id = await self.start_kernel_for_session(
+                session_id, path, name, type, kernel_name
+            )
+        result = await self.save_session(
+            session_id, path=path, name=name, type=type, kernel_id=kernel_id
+        )
         return result
 
     async def start_kernel_for_session(self, session_id, path, name, type, kernel_name):
         """Start a new kernel for a given session."""
         # allow contents manager to specify kernels cwd
         kernel_path = self.contents_manager.get_kernel_path(path=path)
-        kernel_id = await self.kernel_manager.start_kernel(path=kernel_path, kernel_name=kernel_name)
+        kernel_id = await self.kernel_manager.start_kernel(
+            path=kernel_path, kernel_name=kernel_name
+        )
         return kernel_id
 
     async def save_session(self, session_id, path=None, name=None, type=None, kernel_id=None):
@@ -124,8 +132,8 @@ class SessionManager(LoggingConfigurable):
         model : dict
             a dictionary of the session model
         """
-        self.cursor.execute("INSERT INTO session VALUES (?,?,?,?,?)",
-            (session_id, path, name, type, kernel_id)
+        self.cursor.execute(
+            "INSERT INTO session VALUES (?,?,?,?,?)", (session_id, path, name, type, kernel_id)
         )
         result = await self.get_session(session_id=session_id)
         return result
@@ -157,7 +165,7 @@ class SessionManager(LoggingConfigurable):
                 raise TypeError("No such column: %r", column)
             conditions.append("%s=?" % column)
 
-        query = "SELECT * FROM session WHERE %s" % (' AND '.join(conditions))
+        query = "SELECT * FROM session WHERE %s" % (" AND ".join(conditions))
 
         self.cursor.execute(query, list(kwargs.values()))
         try:
@@ -171,7 +179,7 @@ class SessionManager(LoggingConfigurable):
             for key, value in kwargs.items():
                 q.append("%s=%r" % (key, value))
 
-            raise web.HTTPError(404, u'Session not found: %s' % (', '.join(q)))
+            raise web.HTTPError(404, u"Session not found: %s" % (", ".join(q)))
 
         model = await self.row_to_model(row)
         return model
@@ -202,7 +210,7 @@ class SessionManager(LoggingConfigurable):
             if column not in self._columns:
                 raise TypeError("No such column: %r" % column)
             sets.append("%s=?" % column)
-        query = "UPDATE session SET %s WHERE session_id=?" % (', '.join(sets))
+        query = "UPDATE session SET %s WHERE session_id=?" % (", ".join(sets))
         self.cursor.execute(query, list(kwargs.values()) + [session_id])
 
     def kernel_culled(self, kernel_id):
@@ -211,7 +219,7 @@ class SessionManager(LoggingConfigurable):
 
     async def row_to_model(self, row, tolerate_culled=False):
         """Takes sqlite database session row and turns it into a dictionary"""
-        kernel_culled = await ensure_async(self.kernel_culled(row['kernel_id']))
+        kernel_culled = await ensure_async(self.kernel_culled(row["kernel_id"]))
         if kernel_culled:
             # The kernel was culled or died without deleting the session.
             # We can't use delete_session here because that tries to find
@@ -220,27 +228,29 @@ class SessionManager(LoggingConfigurable):
             # If caller wishes to tolerate culled kernels, log a warning
             # and return None.  Otherwise, raise KeyError with a similar
             # message.
-            self.cursor.execute("DELETE FROM session WHERE session_id=?",
-                                (row['session_id'],))
-            msg = "Kernel '{kernel_id}' appears to have been culled or died unexpectedly, " \
-                  "invalidating session '{session_id}'. The session has been removed.".\
-                format(kernel_id=row['kernel_id'],session_id=row['session_id'])
+            self.cursor.execute("DELETE FROM session WHERE session_id=?", (row["session_id"],))
+            msg = (
+                "Kernel '{kernel_id}' appears to have been culled or died unexpectedly, "
+                "invalidating session '{session_id}'. The session has been removed.".format(
+                    kernel_id=row["kernel_id"], session_id=row["session_id"]
+                )
+            )
             if tolerate_culled:
                 self.log.warning(msg + "  Continuing...")
                 return
             raise KeyError(msg)
 
-        kernel_model = await ensure_async(self.kernel_manager.kernel_model(row['kernel_id']))
+        kernel_model = await ensure_async(self.kernel_manager.kernel_model(row["kernel_id"]))
         model = {
-            'id': row['session_id'],
-            'path': row['path'],
-            'name': row['name'],
-            'type': row['type'],
-            'kernel': kernel_model
+            "id": row["session_id"],
+            "path": row["path"],
+            "name": row["name"],
+            "type": row["type"],
+            "kernel": kernel_model,
         }
-        if row['type'] == 'notebook':
+        if row["type"] == "notebook":
             # Provide the deprecated API.
-            model['notebook'] = {'path': row['path'], 'name': row['name']}
+            model["notebook"] = {"path": row["path"], "name": row["name"]}
         return model
 
     async def list_sessions(self):
@@ -261,5 +271,5 @@ class SessionManager(LoggingConfigurable):
     async def delete_session(self, session_id):
         """Deletes the row in the session database with given session_id"""
         session = await self.get_session(session_id=session_id)
-        await ensure_async(self.kernel_manager.shutdown_kernel(session['kernel']['id']))
+        await ensure_async(self.kernel_manager.shutdown_kernel(session["kernel"]["id"]))
         self.cursor.execute("DELETE FROM session WHERE session_id=?", (session_id,))
